@@ -7,3 +7,9 @@ class NOTICE_COLUMN_NAME(Choice):
     notice_type = _('notice type')
     sender = _('sender')
     date_field = _('date')
+
+
+class NOTICE_TYPE(Choice):
+    READ = 0, _('read').title()
+    NEW = 1, _('new').title()
+    ALL = 2, _('all').title()
